# nidhoggr-core

This package contains all domain model for [nighoggr] library for
convenient interop with other Python applications (like
[nidhoggr-requests]).

[nidhoggr]: https://pypi.org/project/nidhoggr/
[nidhoggr-requests]: https://pypi.org/project/nidhoggr-requests/
